Learn R Programming

europeanaR (version 0.1.0)

get_key: Get API key

Description

This function is a simple wrapper of the `Sys.getenv` base function. It gets the value of the environmental variable `EUROPEANA_KEY`.

Usage

get_key()

Arguments

Value

character with the API key stored as environmental variable

See Also

set_key