This function is a simple wrapper of the `Sys.setenv` base
function. It sets the value of the environmental variable `EUROPEANA_KEY`.
Alternatively, use .Renviron to set the key. Get and API key in the
following link https://pro.europeana.eu/page/get-api.